@@ -23,23 +23,38 @@ createWorkbook <- function(type="xlsx")
 
 ######################################################################
 # 
-loadWorkbook <- function(file)
+loadWorkbook <- function(file, password=NULL)
 {
   if (!file.exists(path.expand(file)))
     stop("Cannot find ", path.expand(file))
+
+  if (is.null(password)) {
+    inputStream <- .jnew("java/io/FileInputStream", path.expand(file))
+    wbFactory <- .jnew("org/apache/poi/ss/usermodel/WorkbookFactory")
+    wb <- wbFactory$create(inputStream)
     
-  inputStream <- .jnew("java/io/FileInputStream", path.expand(file))
+  } else {
+    file <- .jnew("java/io/File", path.expand(file))
+    fileSystem <-new(J("org/apache/poi/poifs/filesystem/NPOIFSFileSystem"),
+                     file)
+    info <- new(J("org/apache/poi/poifs/crypt/EncryptionInfo"),
+                 fileSystem)
+    decryptor <- J(info, "getDecryptor")
+    verification <- J(decryptor, "verifyPassword", password)
+    if (!verification) stop("password does not verify")
+    dataStream <- J(decryptor, "getDataStream", fileSystem)
+    wb <- new(J("org/apache/poi/xssf/usermodel/XSSFWorkbook"),
+              dataStream)  
+  } 
+
   
-  wbFactory <- .jnew("org/apache/poi/ss/usermodel/WorkbookFactory")
-  
-  wb <- wbFactory$create(inputStream)
-    
   return(wb)
 }
 
+
 ######################################################################
 # 
-saveWorkbook <- function(wb, file)
+saveWorkbook <- function(wb, file, password=NULL)
 {
   jFile <- .jnew("java/io/File", file)
   fh <- .jnew("java/io/FileOutputStream", jFile)
@@ -49,7 +64,31 @@ saveWorkbook <- function(wb, file)
   
   # close the filehandle
   .jcall(fh, "V", "close")
+
+  if ( !is.null(password) ) {
+    fs <- .jnew("org/apache/poi/poifs/filesystem/POIFSFileSystem")
+    encMode <- J("org/apache/poi/poifs/crypt/EncryptionMode", "valueOf", "agile")
+    info <- .jnew("org/apache/poi/poifs/crypt/EncryptionInfo", encMode)
+
+    enc <- info$getEncryptor()
+    enc$confirmPassword(password)
+
+    access <- J("org.apache.poi.openxml4j.opc.PackageAccess", "valueOf", "READ_WRITE")
+    opc <- J("org.apache.poi.openxml4j.opc.OPCPackage", "open", jFile, access)
+    outputStream <- enc$getDataStream(fs)
+    opc$save(outputStream)
+    opc$close()
+
+    fos <- .jnew("java/io/FileOutputStream", file)
+    fs$writeFilesystem(fos)
+    fos$close()
+  }
+
+  invisible()
 }
+
+
+
 ## # make a file handle and write the xlsx to file
 ## filename <- "C:/Temp/junk.xlsx"
 ## fh <- .jnew("java/io/FileOutputStream", filename)
